function fireworksHelp

txt = {...
    '<F1>', 'Plain fireworks (random direction)';
    '<F2>', 'Glitter fireworks (random direction)';
    '<F3>', 'Heart shape (random direction)';
    '<F4>', 'MATLAB logo (random direction)';
    '<F10>', 'Toggle Record Mode (no audio)';
    '<F12>', 'Toggle Demo Mode (randomly cycle through Presets)';
    '<space>', 'Random fireworks from center';
    '<1> - <0>', 'Presets 1 through 10';
    '<letter keys>, <!>, <?>', 'Letter fireworks (random direction)';
    'Mouse click', 'Random fireworks from clicked location (horizontal)';
    '(right) Click-drag-release', 'Series of random fireworks along the swept path';
    '(left) Click-drag-release', 'Series of vertical fireworks along the swept path';
    'Scroll wheel (up)', 'Rapid-fire vertical fireworks (from cursor location)';};

fh = findall(0, 'Type', 'Figure', 'Tag', 'AboutFireworksDialog');
if ishandle(fh)
    figure(fh);
    return;
end
fh = figure('units', 'pixels', 'visible', 'off', 'resize', 'off', ...
    'menu', 'none', 'toolbar', 'none', 'numbertitle', 'off', ...
    'Tag', 'AboutFireworksDialog', 'HandleVisibility', 'off', ...
    'CloseRequestFcn', @figCloseFcn, 'name', 'About Fireworks GUI');
ah = axes('Parent', fh, 'XLim', [0 1], 'YLim', [0 1], 'units', 'pixels', 'visible', 'off');
th(1) = text(0, 0, txt(:, 1), ...
    'Parent', ah, ...
    'FontName', 'Verdana', ...
    'HorizontalAlignment', 'right', ...
    'VerticalAlignment', 'top');
th(2) = text(0, 0, txt(:, 2), ...
    'Parent', ah, ...
    'FontName', 'Verdana', ...
    'HorizontalAlignment', 'left', ...
    'VerticalAlignment', 'top');
th(3) = text(0, 0, ...
    {'Written by Jiro Doke (jiro.doke@mathworks.com)', 'Copyright 2010 The MathWorks, Inc.'}, ...
    'Parent', ah, ...
    'FontName', 'Verdana', ...
    'FontSize', 8, ...
    'HorizontalAlignment', 'left', ...
    'VerticalAlignment', 'bottom');
th(4) = text(0, 0, ...
    {'v1.0'}, ...
    'Parent', ah, ...
    'FontName', 'Verdana', ...
    'FontSize', 8, ...
    'HorizontalAlignment', 'right', ...
    'VerticalAlignment', 'bottom');

set(th, 'Units', 'pixels');

te = get(th, 'Extent');

set(fh, 'position', [0, 0, te{1}(3)+te{2}(3)+60, te{1}(4)+te{3}(4)+70]);
set(ah, 'position', [0, 0, te{1}(3)+te{2}(3)+60, te{1}(4)+te{3}(4)+70]);
set(th(1), 'Position', [te{1}(3)+30, te{1}(4)+te{3}(4)+50]);
set(th(2), 'Position', [te{1}(3)+40, te{2}(4)+te{3}(4)+50]);
set(th(3), 'Position', [5, 5]);
set(th(4), 'Position', [te{1}(3)+te{2}(3)+55, 5]);

ah2 = axes(...
    'Parent', fh, ...
    'units', 'pixels', ...
    'position', [10, te{1}(4)+te{3}(4)-15, 80, 80]);

uicontrol(...
    'Parent', fh, ...
    'Style', 'pushbutton', ...
    'FontUnits', 'pixels', ...
    'FontSize', 15, ...
    'String', 'Class Documentation', ...
    'Callback', @(o, e) doc('Sky'), ...
    'Units', 'pixels', ...
    'Position', [te{1}(3)+te{2}(3)-240, 25, 180, 30]);
uicontrol(...
    'Parent', fh, ...
    'Style', 'pushbutton', ...
    'FontUnits', 'pixels', ...
    'FontSize', 15, ...
    'String', 'Close', ...
    'Callback', @figCloseFcn, ...
    'Units', 'pixels', ...
    'Position', [te{1}(3)+te{2}(3)-50, 25, 100, 30]);

f = Fireworks(ah2, 4, 'ThinLine', true, 'HaveSound', false);

t = timer(...
    'Name', 'HelpDialogTimer', ...
    'Period', 0.015, ...
    'ExecutionMode', 'fixedSpacing', ...
    'TimerFcn', @stepFireworks);

movegui(fh, 'center');
set(fh, 'visible','on');

start(t);

    function stepFireworks(varargin)
        s = step(f);
        newFireworks(f(~s), 'ThinLine', true, 'HaveSound', false);
    end

    function figCloseFcn(varargin)
        if isvalid(t)
            stop(t);
            while strcmpi(t.Running, 'on'), end
            delete(t);
        end
        delete(f);
        delete(fh);
    end

end